Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/MHSanaei/3x-ui.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--x-ui.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/x-ui.sh b/x-ui.sh
index 9816f4a7..8a833ed5 100644
--- a/x-ui.sh
+++ b/x-ui.sh
@@ -1278,8 +1278,8 @@ run_speedtest() {
}
create_iplimit_jails() {
- # Use default bantime if not passed => 15 minutes
- local bantime="${1:-15}"
+ # Use default bantime if not passed => 30 minutes
+ local bantime="${1:-30}"
# Uncomment 'allowipv6 = auto' in fail2ban.conf
sed -i 's/#allowipv6 = auto/allowipv6 = auto/g' /etc/fail2ban/fail2ban.conf